==> kubernetes-model-storageclass-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/storage/v1beta1/CSINodeDriverFluent.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CSINodeDriverFluent<A extends CSINodeDriverFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAllocatable instead.
 * @return The buildable object.
 */
@Deprecated public VolumeNodeResources getAllocatable();
    public VolumeNodeResources buildAllocatable();
    public A withAllocatable(VolumeNodeResources allocatable);
    public Boolean hasAllocatable();
    public A withNewAllocatable(Integer count);
    public CSINodeDriverFluent.AllocatableNested<A> withNewAllocatable();
    public CSINodeDriverFluent.AllocatableNested<A> withNewAllocatableLike(VolumeNodeResources item);
    public CSINodeDriverFluent.AllocatableNested<A> editAllocatable();
    public CSINodeDriverFluent.AllocatableNested<A> editOrNewAllocatable();
    public CSINodeDriverFluent.AllocatableNested<A> editOrNewAllocatableLike(VolumeNodeResources item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getNodeID();
    public A withNodeID(String nodeID);
    public Boolean hasNodeID();
    public A withNewNodeID(String arg1);
    public A withNewNodeID(StringBuilder arg1);
    public A withNewNodeID(StringBuffer arg1);
    public A addToTopologyKeys(int index,String item);
    public A setToTopologyKeys(int index,String item);
    public A addToTopologyKeys(String... items);
    public A addAllToTopologyKeys(Collection<String> items);
    public A removeFromTopologyKeys(String... items);
    public A removeAllFromTopologyKeys(Collection<String> items);
    public List<String> getTopologyKeys();
    public String getTopologyKey(int index);
    public String getFirstTopologyKey();
    public String getLastTopologyKey();
    public String getMatchingTopologyKey(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingTopologyKey(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withTopologyKeys(List<String> topologyKeys);
    public A withTopologyKeys(String... topologyKeys);
    public Boolean hasTopologyKeys();
    public A addNewTopologyKey(String arg1);
    public A addNewTopologyKey(StringBuilder arg1);
    public A addNewTopologyKey(StringBuffer arg1);
    public interface AllocatableNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,VolumeNodeResourcesFluent<CSINodeDriverFluent.AllocatableNested<N>> {

        public N and();
        public N endAllocatable();    }


}

==> kubernetes-model-storageclass-5.0.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/storage/v1beta1/CSINodeDriverFluent.java <==
package io.fabric8.kubernetes.api.model.storage.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CSINodeDriverFluent<A extends CSINodeDriverFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAllocatable instead.
 * @return The buildable object.
 */
@Deprecated public VolumeNodeResources getAllocatable();
    public VolumeNodeResources buildAllocatable();
    public A withAllocatable(VolumeNodeResources allocatable);
    public Boolean hasAllocatable();
    public A withNewAllocatable(Integer count);
    public CSINodeDriverFluent.AllocatableNested<A> withNewAllocatable();
    public CSINodeDriverFluent.AllocatableNested<A> withNewAllocatableLike(VolumeNodeResources item);
    public CSINodeDriverFluent.AllocatableNested<A> editAllocatable();
    public CSINodeDriverFluent.AllocatableNested<A> editOrNewAllocatable();
    public CSINodeDriverFluent.AllocatableNested<A> editOrNewAllocatableLike(VolumeNodeResources item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getNodeID();
    public A withNodeID(String nodeID);
    public Boolean hasNodeID();
    public A withNewNodeID(String arg1);
    public A withNewNodeID(StringBuilder arg1);
    public A withNewNodeID(StringBuffer arg1);
    public A addToTopologyKeys(int index,String item);
    public A setToTopologyKeys(int index,String item);
    public A addToTopologyKeys(String... items);
    public A addAllToTopologyKeys(Collection<String> items);
    public A removeFromTopologyKeys(String... items);
    public A removeAllFromTopologyKeys(Collection<String> items);
    public List<String> getTopologyKeys();
    public String getTopologyKey(int index);
    public String getFirstTopologyKey();
    public String getLastTopologyKey();
    public String getMatchingTopologyKey(Predicate<String> predicate);
    public Boolean hasMatchingTopologyKey(Predicate<String> predicate);
    public A withTopologyKeys(List<String> topologyKeys);
    public A withTopologyKeys(String... topologyKeys);
    public Boolean hasTopologyKeys();
    public A addNewTopologyKey(String arg1);
    public A addNewTopologyKey(StringBuilder arg1);
    public A addNewTopologyKey(StringBuffer arg1);
    public interface AllocatableNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,VolumeNodeResourcesFluent<CSINodeDriverFluent.AllocatableNested<N>> {

            public N and();
            public N endAllocatable();    }


}
